from typing import Literal

BackgroundImage = Literal[
    'none',
    'gradient-to-t',
    'gradient-to-tr',
    'gradient-to-r',
    'gradient-to-br',
    'gradient-to-b',
    'gradient-to-bl',
    'gradient-to-l',
    'gradient-to-tl',
]
